@@ -1,10 +1,12 @@
 from __future__ import annotations
-from reamber.o2jam.lists.notes.O2JNoteList import O2JNoteList
-from reamber.o2jam.O2JHitObj import O2JHitObj
+
 from typing import List
 
+from reamber.o2jam.O2JHit import O2JHit
+from reamber.o2jam.lists.notes.O2JNoteList import O2JNoteList
 
-class O2JHitList(List[O2JHitObj], O2JNoteList):
+
+class O2JHitList(List[O2JHit], O2JNoteList):
 
     def _upcast(self, objList: List = None) -> O2JHitList:
         """ This is to facilitate inherited functions to work
@@ -14,5 +16,5 @@ class O2JHitList(List[O2JHitObj], O2JNoteList):
         """
         return O2JHitList(objList)
 
-    def data(self) -> List[O2JHitObj]:
+    def data(self) -> List[O2JHit]:
         return self
