@@ -1,11 +1,13 @@
 from __future__ import annotations
-from reamber.o2jam.lists.notes.O2JNoteList import O2JNoteList
-from reamber.o2jam.O2JHoldObj import O2JHoldObj
-from reamber.base.lists.notes.HoldList import HoldList
+
 from typing import List
 
+from reamber.base.lists.notes.HoldList import HoldList
+from reamber.o2jam.O2JHold import O2JHold
+from reamber.o2jam.lists.notes.O2JNoteList import O2JNoteList
 
-class O2JHoldList(List[O2JHoldObj], O2JNoteList, HoldList):
+
+class O2JHoldList(List[O2JHold], HoldList, O2JNoteList):
 
     def _upcast(self, objList: List = None) -> O2JNoteList:
         """ This is to facilitate inherited functions to work
@@ -15,5 +17,8 @@ class O2JHoldList(List[O2JHoldObj], O2JNoteList, HoldList):
         """
         return O2JHoldList(objList)
 
-    def data(self) -> List[O2JHoldObj]:
+    def multOffset(self, by: float, inplace:bool = False):
+        HoldList.multOffset(self, by=by, inplace=inplace)
+
+    def data(self) -> List[O2JHold]:
         return self
