@@ -1,10 +1,12 @@
 from __future__ import annotations
+
 from typing import List
-from reamber.osu.OsuSampleObj import OsuSampleObj
+
 from reamber.base.lists.TimedList import TimedList
+from reamber.osu.OsuSample import OsuSample
 
 
-class OsuSampleList(List[OsuSampleObj], TimedList):
+class OsuSampleList(List[OsuSample], TimedList):
 
     def _upcast(self, objList: List = None) -> OsuSampleList:
         """ This is to facilitate inherited functions to work
@@ -14,7 +16,7 @@ class OsuSampleList(List[OsuSampleObj], TimedList):
         """
         return OsuSampleList(objList)
 
-    def data(self) -> List[OsuSampleObj]:
+    def data(self) -> List[OsuSample]:
         return self
 
     def sampleFiles(self) -> List[str]:
