@@ -1,10 +1,12 @@
 from __future__ import annotations
-from reamber.base.lists.TimedList import TimedList
-from reamber.osu.OsuSvObj import OsuSvObj
+
 from typing import List
 
+from reamber.base.lists.TimedList import TimedList
+from reamber.osu.OsuSv import OsuSv
 
-class OsuSvList(List[OsuSvObj], TimedList):
+
+class OsuSvList(List[OsuSv], TimedList):
 
     def _upcast(self, objList: List = None) -> OsuSvList:
         """ This is to facilitate inherited functions to work
@@ -14,7 +16,7 @@ class OsuSvList(List[OsuSvObj], TimedList):
         """
         return OsuSvList(objList)
 
-    def data(self) -> List[OsuSvObj]:
+    def data(self) -> List[OsuSv]:
         return self
 
     def multipliers(self) -> List[float]:
