@@ -1,11 +1,13 @@
 from __future__ import annotations
-from reamber.sm.lists.notes.SMNoteList import SMNoteList
-from reamber.sm.SMHoldObj import SMHoldObj
-from reamber.base.lists.notes.HoldList import HoldList
+
 from typing import List
 
+from reamber.base.lists.notes.HoldList import HoldList
+from reamber.sm.SMHold import SMHold
+from reamber.sm.lists.notes.SMNoteList import SMNoteList
 
-class SMHoldList(List[SMHoldObj], HoldList, SMNoteList):
+
+class SMHoldList(List[SMHold], HoldList, SMNoteList):
 
     def _upcast(self, objList: List = None) -> SMHoldList:
         """ This is to facilitate inherited functions to work
@@ -15,5 +17,8 @@ class SMHoldList(List[SMHoldObj], HoldList, SMNoteList):
         """
         return SMHoldList(objList)
 
-    def data(self) -> List[SMHoldObj]:
+    def multOffset(self, by: float, inplace:bool = False):
+        HoldList.multOffset(self, by=by, inplace=inplace)
+
+    def data(self) -> List[SMHold]:
         return self
