@@ -1,10 +1,12 @@
 from __future__ import annotations
-from reamber.sm.lists.notes.SMNoteList import SMNoteList
-from reamber.sm.SMLiftObj import SMLiftObj
+
 from typing import List
 
+from reamber.sm.SMLift import SMLift
+from reamber.sm.lists.notes.SMNoteList import SMNoteList
 
-class SMLiftList(List[SMLiftObj], SMNoteList):
+
+class SMLiftList(List[SMLift], SMNoteList):
 
     def _upcast(self, objList: List = None) -> SMLiftList:
         """ This is to facilitate inherited functions to work
@@ -14,5 +16,5 @@ class SMLiftList(List[SMLiftObj], SMNoteList):
         """
         return SMLiftList(objList)
 
-    def data(self) -> List[SMLiftObj]:
+    def data(self) -> List[SMLift]:
         return self
