@@ -2,11 +2,17 @@ import os
 
 _MAPS_DIR = os.path.dirname(os.path.realpath(__file__)) + "/../../rsc/maps/"
 
+_BMS_DIR = _MAPS_DIR + "bms/"
 _O2J_DIR = _MAPS_DIR + "o2jam/"
 _OSU_DIR = _MAPS_DIR + "osu/"
 _QUA_DIR = _MAPS_DIR + "qua/"
 _SM_DIR = _MAPS_DIR + "sm/"
 
+BMS_COLD_BREATH = _BMS_DIR + "coldBreath.bme"
+BMS_SEAROAD = _BMS_DIR + "searoad.bml"
+BMS_SAMBALAND = _BMS_DIR + "sambaland.bme"
+BMS_SUPERIZANAGI = _BMS_DIR + "superIzanagi.bme"
+
 O2J_CHECK_IT_OUT_OJN = _O2J_DIR + "o2ma120.ojn"
 O2J_CHECK_IT_OUT_OJM = _O2J_DIR + "o2ma120.ojm"
 O2J_FLY_MAGPIE_OJN = _O2J_DIR + "o2ma178.ojn"
@@ -21,14 +27,11 @@ OSU_AVENGER_HITSOUNDFILE = _OSU_DIR + "AvengerHitsoundFile.osu"
 OSU_CARAVAN = _OSU_DIR + "Caravan.osu"
 OSU_CHECK_IT_OUT = _OSU_DIR + "CheckItOut.osu"
 OSU_DOPPELGANGER = _OSU_DIR + "DoppelGanger.osu"
-OSU_DOOM_BUTTERFLY = _OSU_DIR + "DoomButterfly.osu"
-OSU_END_TIME = _OSU_DIR + "EndTime.osu"
 OSU_ESCAPES = _OSU_DIR + "Escapes.osu"
 OSU_FOOL_MOON_NIGHT = _OSU_DIR + "FoolMoonNight.osu"
 OSU_GRAVITY = _OSU_DIR + "Gravity.osu"
 OSU_ICFITU = _OSU_DIR + "ICFITU.osu"
 OSU_JOUNETSU = _OSU_DIR + "JounetsuTairiku.osu"
-OSU_LAST_RESORT = _OSU_DIR + "LastResort.osu"
 OSU_LEG = _OSU_DIR + "LEG.osu"
 OSU_LN_DAN_14 = _OSU_DIR + "LNDan14.osu"
 OSU_LN_DAN_15 = _OSU_DIR + "LNDan15.osu"
@@ -43,6 +46,7 @@ OSU_ZENITHALIZE_19 = _OSU_DIR + "ZENITHALIZE_19.osu"
 OSU_ZENITH = _OSU_DIR + "Zenith.osu"
 
 QUA_NEURO_CLOUD = _QUA_DIR + "NeuroCloud.qua"
+QUA_CARRY_ME_AWAY = _QUA_DIR + "CarryMeAway.qua"
 
 SM_CARAVAN = _SM_DIR + "Caravan.sm"
 SM_ESCAPES = _SM_DIR + "Escapes.sm"
