@@ -13,27 +13,14 @@ from tests.test.RSC_PATHS import *
 class TestOsuToQua(unittest.TestCase):
 
     # @profile
-    def test_o2j1(self):
+    def test(self):
         # Complex BPM Points
-        o2j = O2JMapSet()
-        o2j.readFile(O2J_FLY_MAGPIE_OJN)
+        o2j = O2JMapSet.readFile(O2J_FLY_MAGPIE_OJN)
 
         osus = O2JToOsu.convert(o2j)
-        osus[0].writeFile("out.osu")
-        osus[1].writeFile("out.osu")
-        osus[2].writeFile("out.osu")
-
-    # @profile
-    def test_o2j2(self):
-        # Complex BPM Points
-        o2j = O2JMapSet()
-        o2j.readFile(O2J_CHECK_IT_OUT_OJN)
-
-        osus = O2JToOsu.convert(o2j)
-        osus[0].writeFile("out.osu")
-        osus[1].writeFile("out.osu")
-        osus[2].writeFile("out.osu")
-
+        # osus[0].writeFile("out.osu")
+        # osus[1].writeFile("out.osu")
+        # osus[2].writeFile("out.osu")
 
 if __name__ == '__main__':
     unittest.main()
