@@ -13,8 +13,7 @@ from reamber.algorithms.pattern.combos.PtnCombo import PtnCombo
 class TestImagePattern(unittest.TestCase):
 
     def test_osu(self):
-        osu = OsuMap()
-        osu.readFile(OSU_BOOGIE)
+        osu = OsuMap.readFile(OSU_BOOGIE)
 
         ptn = Pattern.fromPkg([osu.notes.hits(), osu.notes.holds()])
         grp = ptn.group(hwindow=None, vwindow=50, avoidJack=True)
@@ -29,7 +28,7 @@ class TestImagePattern(unittest.TestCase):
              + PFDrawLines.fromCombo(keys=keys, **PFDrawLines.Colors.PURPLE,
             combo=PtnCombo(grp).templateJacks(minimumLength=2, keys=keys))
 
-        pf.exportFold(maxHeight=1750, stageLineWidth=0).save("osu.png")
+        # pf.exportFold(maxHeight=1750, stageLineWidth=0).save("osu.png")
 
         pass
 
