@@ -12,17 +12,15 @@ class TestNps(unittest.TestCase):
     # @profile
     def test(self):
         plt.clf()
-        m = OsuMap()
-        m.readFile(OSU_PLANET_SHAPER)
+        m = OsuMap.readFile(OSU_PLANET_SHAPER)
         npsPlot(m.notes)
-        plt.savefig('main.png')
+        # plt.savefig('main.png')
 
     def testByKey(self):
         plt.clf()
-        m = OsuMap()
-        m.readFile(OSU_PLANET_SHAPER)
+        m = OsuMap.readFile(OSU_PLANET_SHAPER)
         npsPlotByKey(m.notes)
-        plt.savefig('byKey.png')
+        # plt.savefig('byKey.png')
 
 
 if __name__ == '__main__':
